#!/usr/bin/Rscript --vanilla

require(ggplot2)
require(dplyr)
require(latex2exp)
require(scales)

require(magrittr)

library(reshape2)
library(hexbin)
library(gridExtra)
library(scales)
library(RColorBrewer)

library(stringr)
require(tikzDevice)

black <- "#000000"
orange <- "#E69F00"
yellow <- "#cccc20"
grey <- "#999999"
cyan <- "#56B4E9"
green <- "#009E73"
dkgreen <- "#006666"
blue <- "#0072B2"
red <- "#D52E00"
purple <- "#CC79A7"
dpurple <- '#882277'

blue <- "#d7191c"
red <- "#2b83ba"
green <- "#abdda4"
purple <- "#fdae61"

pal <- brewer.pal(4, "Set1")
blue <- pal[1]
red <- pal[2]
green <- pal[3]
purple <- pal[4]


latex_percent <- function (x) {
  x <- plyr::round_any(x, scales:::precision(x)/100)
  stringr::str_c(comma(x * 100), "\\%")
}

palette <- c( blue,red, green,purple,orange,dkgreen, cyan)


df <- read.csv("../run/results.csv",header = T)



get_cost_table <- function(d)
{
    r <- d[, FALSE]
    r$log_DP_five <- ((d$log_DP_five+d$LB_cost) / (d$DP+d$LB_cost))
    r$NFGS <- ((d$NFGS+d$LB_cost) / (d$DP+d$LB_cost))
    r$log_NFGS <- ((d$log_NFGS+d$LB_cost) / (d$DP+d$LB_cost))
    r$FGS <- ((d$FGS+d$LB_cost) / (d$DP+d$LB_cost))
    r$No_detour <- ((d$No_detour+d$LB_cost) / (d$DP+d$LB_cost))
    r$GS <- ((d$GS+d$LB_cost) / (d$DP+d$LB_cost))
    r$log_DP_one <- ((d$log_DP_one+d$LB_cost) / (d$DP+d$LB_cost))
  return (r)
}


plot_ecdf <- function(ratio, heurs, xmax)
{
  heur<-ratio[,heurs]
  labels <- heurs
  labels <- replace(labels, labels=='FGS','FGS')
  labels <- replace(labels, labels=='NFGS','NFGS')
  labels <- replace(labels, labels=='GS','GS')
  labels <- replace(labels, labels=='log_NFGS','LogNFGS')
  labels <- replace(labels, labels=='log_DP_five','LogDP(5)')
  labels <- replace(labels, labels=='No_detour','NoDetour')
  labels <- replace(labels, labels=='log_DP_one','LogDP(1)')
  return (plot(ggplot(melt(heur-1),aes(value, colour=variable, linetype=variable)) + stat_ecdf()+ 
                 xlab("Maximal overhead") + theme_bw() +
                 theme(legend.position = "top", legend.justification = "left",
                       legend.margin = margin(0,0,0,0),
                       legend.box.margin = margin(-10,-10,-10,-10)) +
                 ylab("Fraction of test cases")  + scale_x_continuous(labels=latex_percent)+
                 scale_colour_manual(name = element_blank(), breaks=heurs, labels=labels, values=palette)+ 
                 scale_linetype_manual(name = element_blank(), breaks=heurs, values=c(1,5,2,3,4,1,6), labels=labels)+
                 coord_cartesian(xlim = c(0,xmax))  ))
}


print_tikz <- function(file,ratio, heurs,xmax)
{
  tikz(paste(c(file,".tex"),collapse=""), standAlone="false",width=4,height=2.25)
  pdf(paste(c(file,".pdf"),collapse=""),width=4,height=2.25)
  p <- plot_ecdf(ratio, heurs, xmax) 
  dev.off()
  return(p)
}

############ stats on time ############ 

summary(df[,c("time_DP","time_log_DP_five","time_No_detour","time_GS","time_FGS","time_NFGS","time_log_NFGS", "time_log_DP_one")])


############ no penalty ############ 
ratio1 <-  get_cost_table(subset(df,penalty_uturn==0))


print_tikz("all_0",ratio1, c("log_DP_five","log_DP_one","FGS","NFGS","log_NFGS","GS","No_detour"), 0.1)  
plot_ecdf(ratio1, c("GS","No_detour"), 4)



############ penalty = half segment ############ 
ratio2 <-  get_cost_table(subset(df,penalty_uturn==14254750000))


plot_ecdf(ratio2, c("GS","No_detour"), 4)
print_tikz("all_0.5",ratio2, c("log_DP_five","log_DP_one","FGS","NFGS","log_NFGS","GS","No_detour"), 0.3)  





############ penalty = segment ############ 
ratio3 <-  get_cost_table(subset(df,penalty_uturn==28509500000))

print_tikz("all_1",ratio3, c("log_DP_five","log_DP_one","FGS","NFGS","log_NFGS","GS","No_detour"), .5)  
plot_ecdf(ratio3, c("GS","No_detour"), 4)




